@@ -1,6 +1,7 @@
 /**************************************************************************
-* Extensible SQLite driver for Qt4
+* Extensible SQLite driver for Qt4/Qt5
 * Copyright (C) 2011-2012 Michał Męciński
+* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2.1
@@ -12,7 +13,7 @@
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
-* along with this library.  If not, see <http://www.gnu.org/licenses/>.
+* along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * This library is based on the QtSql module of the Qt Toolkit
 * Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
@@ -21,20 +22,10 @@
 #include "sqliteextension.h"
 
 #include <QString>
-#include <QRegExp>
 #include <QDebug>
 
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2) || defined(Q_OS_MAC)
-#if QT_VERSION >= 0x050100
-#include <sqlite_qt51x/sqlite3.h>
-#elif QT_VERSION >= 0x040800
-#include <sqlite_qt48x/sqlite3.h>
-#else
-#include <sqlite_qt47x/sqlite3.h>
-#endif
-#else
 #include <sqlite3.h>
-#endif
+#include <qzregexp.h>
 
 static int localeCompare( void* /*arg*/, int len1, const void* data1, int len2, const void* data2 )
 {
@@ -66,7 +57,7 @@ static void regexpFunction( sqlite3_context* context, int /*argc*/, sqlite3_valu
   QString string1 = QString::fromRawData( reinterpret_cast<const QChar*>( data1 ), len1 / sizeof( QChar ) );
   QString string2 = QString::fromRawData( reinterpret_cast<const QChar*>( data2 ), len2 / sizeof( QChar ) );
 
-  QRegExp pattern( string1.toUpper(), Qt::CaseInsensitive, QRegExp::RegExp2 );
+  QzRegExp pattern( string1.toUpper(), Qt::CaseInsensitive);
 
   int pos = pattern.indexIn( string2.toUpper() );
 
@@ -83,7 +74,7 @@ static void upperFunction(sqlite3_context* context, int /*argc*/, sqlite3_value*
   QString string = QString::fromRawData(reinterpret_cast<const QChar*>(data), len/sizeof(QChar));
   string = string.toUpper();
 
-  sqlite3_result_text16(context, string.data(), -1, NULL);
+  sqlite3_result_text16(context, string.data(), -1, SQLITE_TRANSIENT);
 }
 
 void installSQLiteExtension( sqlite3* db )
