@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
@@ -38,8 +38,8 @@
 #include <QSound>
 
 #include "categoriestreewidget.h"
-#include "feedstreemodel.h"
-#include "feedstreeview.h"
+#include "feedsmodel.h"
+#include "feedsview.h"
 #include "findfeed.h"
 #include "newsheader.h"
 #include "newsmodel.h"
@@ -53,6 +53,8 @@
 #include "parseobject.h"
 #include "toolbutton.h"
 
+#define TAB_WIDGET_PERMANENT 0
+
 #define NEW_TAB_FOREGROUND 1
 #define NEW_TAB_BACKGROUND 2
 
@@ -104,11 +106,10 @@ public:
   }
 
   QSqlDatabase db_;
-  FeedsTreeModel *feedsTreeModel_;
+  FeedsModel *feedsModel_;
   FeedsProxyModel *feedsProxyModel_;
-  FeedsTreeView *feedsTreeView_;
+  FeedsView *feedsView_;
   CategoriesTreeWidget *categoriesTree_;
-#define TAB_WIDGET_PERMANENT 0
   QStackedWidget *stackedWidget_;
 
   bool showFeedsTabPermanent_;
@@ -162,6 +163,8 @@ public:
   QAction *bloggerShareAct_;
   QAction *printfriendlyShareAct_;
   QAction *copyLinkAct_;
+  QAction *pageUpWebViewAct_;
+  QAction *pageDownWebViewAct_;
   QAction *nextFolderAct_;
   QAction *prevFolderAct_;
   QAction *expandFolderAct_;
@@ -203,6 +206,8 @@ public:
   QString newsTitleBackgroundColor_;
   QString newsBackgroundColor_;
   QString alternatingRowColors_;
+  QString notifierTextColor_;
+  QString notifierBackgroundColor_;
   QString formatDate_;
   QString formatTime_;
 
@@ -247,10 +252,18 @@ public:
 
   int openNewsTab_;
 
+  int screenNotify_;
   int positionNotify_;
+  int transparencyNotify_;
   int countShowNewsNotify_;
   int widthTitleNewsNotify_;
   int timeShowNewsNotify_;
+  bool showTitlesFeedsNotify_;
+  bool showIconFeedNotify_;
+  bool showButtonMarkAllNotify_;
+  bool showButtonMarkReadNotify_;
+  bool showButtonExBrowserNotify_;
+  bool showButtonDeleteNotify_;
   QList<int> idFeedsNotifyList_;
 
   AdBlockIcon *adBlockIcon() { return adblockIcon_; }
@@ -267,6 +280,7 @@ public slots:
   void setFeedsFilter(bool clicked = true);
   void slotGetFeed();
   void slotGetAllFeeds();
+  void slotStopUpdate();
   void showProgressBar(int addToMaximum);
   void slotSetValue(int value);
   void showMessageStatusBar(QString message, int timeout = 0);
@@ -276,6 +290,7 @@ public slots:
   void showOptionDlg(int index = -1);
   void slotPlaceToTray();
   void slotActivationTray(QSystemTrayIcon::ActivationReason reason);
+  void slotTrayOpenNotifyTimer();
   void showWindows(bool trayClick = false);
   void quitApp();
   void myEmptyWorkingSet();
@@ -286,8 +301,6 @@ public slots:
   void setNewsFilter(QAction*, bool clicked = true);
   void slotCloseTab(int index);
   QWebPage *createWebTab(QUrl url = QUrl());
-  void slotAuthentication(QNetworkReply *reply, QAuthenticator *auth);
-  void slotProxyAuthentication(const QNetworkProxy &proxy, QAuthenticator *auth);
   void feedsModelReload(bool checkFilter = false);
   void setStatusFeed(int feedId, QString status);
   void slotPrint(QWebFrame *frame = 0);
@@ -300,13 +313,14 @@ signals:
   void signalGetFeed(int feedId, QString feedUrl, QDateTime date, int auth);
   void signalGetFeedsFolder(QString query);
   void signalGetAllFeeds();
+  void signalStopUpdate();
   void signalImportFeeds(QByteArray xmlData);
   void signalRequestUrl(int feedId, QString urlString,
                         QDateTime date, QString userInfo);
   void faviconRequestUrl(QString urlString, QString feedUrl);
   void signalIconFeedReady(QString feedUrl, QByteArray faviconData);
   void signalSetCurrentTab(int index, bool updateTab = false);
-  void signalShowNotification();
+  void signalShowNotification(bool bShowRecentNews=false);
   void signalRefreshInfoTray();
   void signalNextUpdate(bool finish);
   void signalRecountCategoryCounts();
@@ -320,6 +334,7 @@ signals:
   void signalRefreshNewsView(int nextUnread);
   void signalSetFeedsFilter(bool clicked = false);
   void signalMarkAllFeedsOld();
+  void signalMarkReadCategory(int type, int idLabel);
 
 private slots:
   void showMainMenu();
@@ -335,7 +350,8 @@ private slots:
   void slotPlaySoundNewNews();
 
 #ifdef HAVE_QT5
-  void mediaStatusChanged(const QMediaPlayer::MediaStatus &status);
+  void mediaStatusChanged(QMediaPlayer::MediaStatus status);
+  void mediaError(QMediaPlayer::Error error);
 #endif
  #ifdef HAVE_PHONON
   void mediaStateChanged(Phonon::State newstate, Phonon::State oldstate);
@@ -373,6 +389,7 @@ private slots:
   void slotTabMoved(int fromIndex, int toIndex);
   void feedsColumnVisible(QAction *action);
   void setNewsLayout(QAction *action);
+  void setNewsLayout();
   void setBrowserPosition(QAction *action);
   void slotOpenNewsWebView();
 
@@ -392,12 +409,14 @@ private slots:
   void slotOpenNewsBackgroundTab();
   void slotCopyLinkNews();
   void slotShowLabelsMenu();
+  void slotPageUpWebView();
+  void slotPageDownWebView();
   void setCurrentTab(int index, bool updateCurrentTab = false);
   void findText();
 
-  void showNotification();
+  void showNotification(bool bShowRecentNews=false);
   void deleteNotification();
-  void clearNotification();
+  void clearNotification(bool bClearRecentNews=false);
   void slotOpenNew(int feedId, int newsId);
   void slotOpenNewBrowser(const QUrl &url);
   void slotMarkReadNewsInNotification(int feedId, int newsId, int read);
@@ -418,12 +437,13 @@ private slots:
   void setStayOnTop();
   void showMenuBar();
 
-  void slotMoveIndex(QModelIndex &indexWhat,QModelIndex &indexWhere, int how);
+  void slotMoveIndex(const QModelIndex &indexWhere, int how);
 
   void slotRefreshInfoTray(int newCount, int unreadCount);
 
   void slotCategoriesClicked(QTreeWidgetItem *item, int, bool createTab = false);
   void clearDeleted();
+  void slotMarkReadCategory(QTreeWidgetItem *item);
   void showNewsCategoriesTree();
   void feedsSplitterMoved(int pos, int);
 
@@ -495,7 +515,6 @@ private:
   void createTabBarWidget();
   void createCentralWidget();
   void loadSettingsFeeds();
-  void appInstallTranslator();
   void retranslateStrings();
   void recountFeedCategories(const QList<int> &categoriesList);
   void creatFeedTab(int feedId, int feedParId);
@@ -519,6 +538,7 @@ private:
 
   QAction *addAct_;
   QAction *addFeedAct_;
+  QAction *addFeedTrayAct_;
   QAction *addFolderAct_;
   QAction *deleteFeedAct_;
   QAction *importFeedsAct_;
@@ -533,6 +553,7 @@ private:
   QAction *customizeNewsToolbarAct_;
   QAction *classicLayoutAct_;
   QAction *newspaperLayoutAct_;
+  QAction *layoutToggle_;
   QAction *systemStyle_;
   QAction *system2Style_;
   QAction *greenStyle_;
@@ -550,6 +571,7 @@ private:
   QAction *setFilterNewsAct_;
   QAction *optionsAct_;
   QAction *updateAllFeedsAct_;
+  QAction *stopUpdateAct_;
   QAction *markAllFeedsRead_;
   QAction *indentationFeedsTreeAct_;
   QAction *sortedByTitleFeedsTreeAct_;
@@ -662,9 +684,6 @@ private:
   QMap<int,int> updateFeedsIntervalSec_;
   QMap<int,int> updateFeedsTimeCount_;
 
-  QTranslator *translator_;
-  QString langFileName_;
-
   bool minimizingTray_;
   bool closingTray_;
   bool singleClickTray_;
@@ -690,6 +709,7 @@ private:
   bool playSoundNewNews_;
   bool showNotifyOn_;
   bool fullscreenModeNotify_;
+  bool showNotifyInactiveApp_;
   bool onlySelectedFeeds_;
 
   UpdateAppDialog *updateAppDialog_;
@@ -706,12 +726,20 @@ private:
   bool cleanUpDeleted_;
   bool optimizeDB_;
 
-  int updateFeedsCount_;
-  QList<int> idFeedList_;
-  QList<int> cntNewNewsList_;
+  struct NewNewsData
+  {
+    QList<int> idFeedList_;
+    QList<int> cntNewsList_;
+  };
+
+  NewNewsData newNews;
+  NewNewsData recentNews;
+
   QList<int> idColorList_;
   QStringList colorList_;
 
+  QTimer timerTrayOpenNotify;
+
   bool reopenFeedStartup_;
   bool openNewTabNextToActive_;
 
