@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 #include "categoriestreewidget.h"
 #include "delegatewithoutfocus.h"
@@ -138,6 +138,9 @@ void CategoriesTreeWidget::showContextMenuCategory(const QPoint &pos)
       if (itemClicked_ == topLevelItem(2)) {
         menu.addSeparator();
         menu.addAction(tr("Clear 'Deleted'"), this, SIGNAL(signalClearDeleted()));
+      } else {
+        menu.addSeparator();
+        menu.addAction(tr("Mark Read"), this, SLOT(slotMarkRead()));
       }
       menu.exec(viewport()->mapToGlobal(pos));
     }
@@ -149,3 +152,8 @@ void CategoriesTreeWidget::openCategoryNewTab()
   setCurrentItem(itemClicked_);
   emit signalMiddleClicked();
 }
+
+void CategoriesTreeWidget::slotMarkRead()
+{
+  emit signalMarkRead(itemClicked_);
+}
