@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2013 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 /*This file is prepared for Doxygen automatic documentation generation.*/
 #include "feedpropertiesdialog.h"
@@ -24,18 +24,19 @@ FeedPropertiesDialog::FeedPropertiesDialog(bool isFeed, QWidget *parent)
 {
   setWindowFlags (windowFlags() & ~Qt::WindowContextHelpButtonHint);
   setWindowTitle(tr("Properties"));
-  setMinimumWidth(450);
-  setMinimumHeight(350);
+  setMinimumWidth(500);
+  setMinimumHeight(400);
 
   tabWidget = new QTabWidget();
-  tabWidget->addTab(CreateGeneralTab(), tr("General"));
-  tabWidget->addTab(CreateColumnsTab(), tr("Columns"));
-  tabWidget->addTab(CreateAuthenticationTab(), tr("Authentication"));
-  tabWidget->addTab(CreateStatusTab(), tr("Status"));
+  tabWidget->addTab(createGeneralTab(), tr("General"));
+  tabWidget->addTab(createDisplayTab(), tr("Display"));
+  tabWidget->addTab(createColumnsTab(), tr("Columns"));
+  int authTabIndex = tabWidget->addTab(createAuthenticationTab(), tr("Authentication"));
+  tabWidget->addTab(createStatusTab(), tr("Status"));
   pageLayout->addWidget(tabWidget);
 
   if (!isFeed_) {
-    tabWidget->removeTab(2);
+    tabWidget->removeTab(authTabIndex);
   }
 
   buttonBox->addButton(QDialogButtonBox::Ok);
@@ -44,14 +45,14 @@ FeedPropertiesDialog::FeedPropertiesDialog(bool isFeed, QWidget *parent)
 
   connect(this, SIGNAL(signalLoadIcon(QString,QString)),
           parent, SIGNAL(faviconRequestUrl(QString,QString)));
-  connect(parent, SIGNAL(signalIconFeedReady(QString, const QByteArray&)),
-          this, SLOT(slotFaviconUpdate(QString, const QByteArray&)));
+  connect(parent, SIGNAL(signalIconFeedReady(QString,QByteArray)),
+          this, SLOT(slotFaviconUpdate(QString,QByteArray)));
 }
 //------------------------------------------------------------------------------
-QWidget *FeedPropertiesDialog::CreateGeneralTab()
+QWidget *FeedPropertiesDialog::createGeneralTab()
 {
   QWidget *tab = new QWidget();
-  QVBoxLayout *layoutGeneralMain = new QVBoxLayout(tab);
+
   QGridLayout *layoutGeneralGrid = new QGridLayout();
   QLabel *labelTitleCapt = new QLabel(tr("Title:"));
   QLabel *labelHomepageCapt = new QLabel(tr("Homepage:"));
@@ -59,7 +60,7 @@ QWidget *FeedPropertiesDialog::CreateGeneralTab()
 
   QHBoxLayout *layoutGeneralTitle = new QHBoxLayout();
   editTitle = new LineEdit();
-  QToolButton *loadTitleButton = new QToolButton();
+  ToolButton *loadTitleButton = new ToolButton();
   loadTitleButton->setIcon(QIcon(":/images/updateFeed"));
   loadTitleButton->setIconSize(QSize(16, 16));
   loadTitleButton->setToolTip(tr("Load Title"));
@@ -81,6 +82,9 @@ QWidget *FeedPropertiesDialog::CreateGeneralTab()
   layoutGeneralTitle->addWidget(selectIconButton_);
   editURL = new LineEdit();
 
+  disableUpdate_ = new QCheckBox(tr("Disable update"));
+  disableUpdate_->setChecked(false);
+
   updateEnable_ = new QCheckBox(tr("Automatically update every"));
   updateInterval_ = new QSpinBox();
   updateInterval_->setEnabled(false);
@@ -103,10 +107,15 @@ QWidget *FeedPropertiesDialog::CreateGeneralTab()
   updateFeedsLayout->addWidget(updateIntervalType_);
   updateFeedsLayout->addStretch();
 
+  connect(disableUpdate_, SIGNAL(toggled(bool)),
+          updateEnable_, SLOT(setDisabled(bool)));
+  connect(disableUpdate_, SIGNAL(toggled(bool)),
+          updateInterval_, SLOT(setDisabled(bool)));
+  connect(disableUpdate_, SIGNAL(toggled(bool)),
+          updateIntervalType_, SLOT(setDisabled(bool)));
+
   starredOn_ = new QCheckBox(tr("Starred"));
-  loadImagesOn = new QCheckBox(tr("Load images"));
   displayOnStartup = new QCheckBox(tr("Display in new tab on startup"));
-  showDescriptionNews_ = new QCheckBox(tr("Show news' description instead of loading web page"));
   duplicateNewsMode_ = new QCheckBox(tr("Automatically delete duplicate news"));
 
   QHBoxLayout *layoutGeneralHomepage = new QHBoxLayout();
@@ -120,16 +129,19 @@ QWidget *FeedPropertiesDialog::CreateGeneralTab()
   layoutGeneralGrid->addWidget(labelURLCapt, 1, 0);
   layoutGeneralGrid->addWidget(editURL, 1, 1);
 
-  layoutGeneralMain->addLayout(layoutGeneralGrid);
-  layoutGeneralMain->addLayout(layoutGeneralHomepage);
-  layoutGeneralMain->addSpacing(15);
-  layoutGeneralMain->addLayout(updateFeedsLayout);
-  layoutGeneralMain->addWidget(starredOn_);
-  layoutGeneralMain->addWidget(loadImagesOn);
-  layoutGeneralMain->addWidget(displayOnStartup);
-  layoutGeneralMain->addWidget(showDescriptionNews_);
-  layoutGeneralMain->addWidget(duplicateNewsMode_);
-  layoutGeneralMain->addStretch();
+  QVBoxLayout *tabLayout = new QVBoxLayout(tab);
+  tabLayout->setMargin(10);
+  tabLayout->setSpacing(5);
+  tabLayout->addLayout(layoutGeneralGrid);
+  tabLayout->addLayout(layoutGeneralHomepage);
+  tabLayout->addSpacing(15);
+  tabLayout->addWidget(disableUpdate_);
+  tabLayout->addLayout(updateFeedsLayout);
+  tabLayout->addSpacing(15);
+  tabLayout->addWidget(starredOn_);
+  tabLayout->addWidget(displayOnStartup);
+  tabLayout->addWidget(duplicateNewsMode_);
+  tabLayout->addStretch();
 
   connect(loadTitleButton, SIGNAL(clicked()), this, SLOT(setDefaultTitle()));
   connect(selectIconButton_, SIGNAL(clicked()),
@@ -153,8 +165,36 @@ QWidget *FeedPropertiesDialog::CreateGeneralTab()
   return tab;
 }
 //------------------------------------------------------------------------------
-QWidget *FeedPropertiesDialog::CreateColumnsTab()
+QWidget *FeedPropertiesDialog::createDisplayTab()
 {
+  QWidget *tab = new QWidget();
+
+  loadImagesOn_ = new QCheckBox(tr("Load images"));
+  loadImagesOn_->setTristate(true);
+  javaScriptEnable_ = new QCheckBox(tr("Enable JavaScript"));
+  javaScriptEnable_->setTristate(true);
+
+  showDescriptionNews_ = new QCheckBox(tr("Show news' description instead of loading web page"));
+
+  layoutDirection_ = new QCheckBox(tr("Right-to-left layout"));
+
+  QVBoxLayout *tabLayout = new QVBoxLayout(tab);
+  tabLayout->setMargin(10);
+  tabLayout->setSpacing(5);
+  tabLayout->addWidget(loadImagesOn_);
+  tabLayout->addWidget(javaScriptEnable_);
+  tabLayout->addWidget(showDescriptionNews_);
+  tabLayout->addWidget(layoutDirection_);
+
+  tabLayout->addStretch();
+
+  return tab;
+}
+//------------------------------------------------------------------------------
+QWidget *FeedPropertiesDialog::createColumnsTab()
+{
+  QWidget *tab = new QWidget();
+
   columnsTree_ = new QTreeWidget(this);
   columnsTree_->setObjectName("columnsTree");
   columnsTree_->setIndentation(0);
@@ -226,21 +266,22 @@ QWidget *FeedPropertiesDialog::CreateColumnsTab()
   buttonsVLayout->addWidget(defaultButton);
   buttonsVLayout->addStretch();
 
-  QHBoxLayout *mainlayout = new QHBoxLayout();
-  mainlayout->addLayout(mainVLayout);
-  mainlayout->addLayout(buttonsVLayout);
+  QHBoxLayout *tabLayout = new QHBoxLayout(tab);
+  tabLayout->setMargin(10);
+  tabLayout->setSpacing(5);
+  tabLayout->addLayout(mainVLayout);
+  tabLayout->addLayout(buttonsVLayout);
 
   connect(columnsTree_, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)),
           this, SLOT(slotCurrentColumnChanged(QTreeWidgetItem*,QTreeWidgetItem*)));
 
-  QWidget *tab = new QWidget();
-  tab->setLayout(mainlayout);
-
   return tab;
 }
 //------------------------------------------------------------------------------
-QWidget *FeedPropertiesDialog::CreateAuthenticationTab()
+QWidget *FeedPropertiesDialog::createAuthenticationTab()
 {
+  QWidget *tab = new QWidget();
+
   authentication_ = new QGroupBox(this);
   authentication_->setTitle(tr("Server requires authentication:"));
   authentication_->setCheckable(true);
@@ -258,24 +299,28 @@ QWidget *FeedPropertiesDialog::CreateAuthenticationTab()
 
   authentication_->setLayout(authenticationLayout);
 
-  QVBoxLayout *layoutMain = new QVBoxLayout();
-  layoutMain->addWidget(authentication_);
-  layoutMain->addStretch(1);
-
-  QWidget *tab = new QWidget();
-  tab->setLayout(layoutMain);
+  QVBoxLayout *tabLayout = new QVBoxLayout(tab);
+  tabLayout->setMargin(10);
+  tabLayout->setSpacing(5);
+  tabLayout->addWidget(authentication_);
+  tabLayout->addStretch(1);
 
   return tab;
 }
 //------------------------------------------------------------------------------
-QWidget *FeedPropertiesDialog::CreateStatusTab()
+QWidget *FeedPropertiesDialog::createStatusTab()
 {
+  QWidget *tab = new QWidget();
+
   statusFeed_ = new QLabel();
   statusFeed_->setWordWrap(true);
   createdFeed_ = new QLabel();
   lastUpdateFeed_ = new QLabel();
   newsCount_ = new QLabel();
 
+  QLabel *feedsCountLabel = new QLabel(tr("Feeds count:"));
+  feedsCount_ = new QLabel();
+
   QLabel *descriptionLabel = new QLabel(tr("Description:"));
 
   descriptionText_ = new QTextEdit();
@@ -291,27 +336,30 @@ QWidget *FeedPropertiesDialog::CreateStatusTab()
   layoutGrid->addWidget(lastUpdateFeed_, 2, 1);
   layoutGrid->addWidget(new QLabel(tr("News count:")), 3, 0);
   layoutGrid->addWidget(newsCount_, 3, 1);
-  layoutGrid->addWidget(descriptionLabel, 4, 0, 1, 1, Qt::AlignTop);
-  layoutGrid->addWidget(descriptionText_, 4, 1, 1, 1, Qt::AlignTop);
+  layoutGrid->addWidget(feedsCountLabel, 4, 0);
+  layoutGrid->addWidget(feedsCount_, 4, 1);
+  layoutGrid->addWidget(descriptionLabel, 5, 0, 1, 1, Qt::AlignTop);
+  layoutGrid->addWidget(descriptionText_, 5, 1, 1, 1, Qt::AlignTop);
 
-  QVBoxLayout *layoutMain = new QVBoxLayout();
-  layoutMain->addLayout(layoutGrid);
-  layoutMain->addStretch(1);
-
-  QWidget *tab = new QWidget();
-  tab->setLayout(layoutMain);
+  QVBoxLayout *tabLayout = new QVBoxLayout(tab);
+  tabLayout->setMargin(10);
+  tabLayout->setSpacing(5);
+  tabLayout->addLayout(layoutGrid);
+  tabLayout->addStretch(1);
 
   if (!isFeed_) {
     descriptionLabel->hide();
     descriptionText_->hide();
+  } else {
+    feedsCountLabel->hide();
+    feedsCount_->hide();
   }
 
   return tab;
 }
 //------------------------------------------------------------------------------
-/*virtual*/ void FeedPropertiesDialog::showEvent(QShowEvent *event)
+/*virtual*/ void FeedPropertiesDialog::showEvent(QShowEvent *)
 {
-  Q_UNUSED(event)
   editTitle->setText(feedProperties.general.text);
   editURL->setText(feedProperties.general.url);
   editURL->selectAll();
@@ -322,13 +370,17 @@ QWidget *FeedPropertiesDialog::CreateStatusTab()
   updateEnable_->setChecked(feedProperties.general.updateEnable);
   updateInterval_->setValue(feedProperties.general.updateInterval);
   updateIntervalType_->setCurrentIndex(feedProperties.general.intervalType + 1);
+  disableUpdate_->setChecked(feedProperties.general.disableUpdate);
 
   displayOnStartup->setChecked(feedProperties.general.displayOnStartup);
   starredOn_->setChecked(feedProperties.general.starred);
-  loadImagesOn->setChecked(feedProperties.display.displayEmbeddedImages);
-  showDescriptionNews_->setChecked(!feedProperties.display.displayNews);
   duplicateNewsMode_->setChecked(feedProperties.general.duplicateNewsMode);
 
+  loadImagesOn_->setCheckState((Qt::CheckState)feedProperties.display.displayEmbeddedImages);
+  javaScriptEnable_->setCheckState((Qt::CheckState)feedProperties.display.javaScriptEnable);
+  showDescriptionNews_->setChecked(!feedProperties.display.displayNews);
+  layoutDirection_->setChecked(feedProperties.display.layoutDirection);
+
   for (int i = 0; i < feedProperties.column.columns.count(); ++i) {
     int index = feedProperties.column.indexList.indexOf(feedProperties.column.columns.at(i));
     QString name = feedProperties.column.nameList.at(index);
@@ -374,6 +426,7 @@ QWidget *FeedPropertiesDialog::CreateStatusTab()
                       arg(tr("new")).
                       arg(feedProperties.status.unreadCount).
                       arg(tr("unread")));
+  feedsCount_->setText(QString("%1").arg(feedProperties.status.feedsCount));
 }
 //------------------------------------------------------------------------------
 void FeedPropertiesDialog::setDefaultTitle()
@@ -452,15 +505,18 @@ FEED_PROPERTIES FeedPropertiesDialog::getFeedProperties()
   feedProperties.general.text = editTitle->text();
   feedProperties.general.url = editURL->text();
 
+  feedProperties.general.disableUpdate = disableUpdate_->isChecked();
   feedProperties.general.updateEnable = updateEnable_->isChecked();
   feedProperties.general.updateInterval = updateInterval_->value();
   feedProperties.general.intervalType = updateIntervalType_->currentIndex() - 1;
 
   feedProperties.general.displayOnStartup = displayOnStartup->isChecked();
   feedProperties.general.starred = starredOn_->isChecked();
-  feedProperties.display.displayEmbeddedImages = loadImagesOn->isChecked();
+  feedProperties.display.displayEmbeddedImages = loadImagesOn_->checkState();
+  feedProperties.display.javaScriptEnable = javaScriptEnable_->checkState();
   feedProperties.display.displayNews = !showDescriptionNews_->isChecked();
   feedProperties.general.duplicateNewsMode = duplicateNewsMode_->isChecked();
+  feedProperties.display.layoutDirection = layoutDirection_->isChecked();
 
   feedProperties.column.columns.clear();
   for (int i = 0; i < columnsTree_->topLevelItemCount(); ++i) {
@@ -484,7 +540,7 @@ void FeedPropertiesDialog::setFeedProperties(FEED_PROPERTIES properties)
 }
 //------------------------------------------------------------------------------
 void FeedPropertiesDialog::slotCurrentColumnChanged(QTreeWidgetItem *current,
-                                                  QTreeWidgetItem *)
+                                                    QTreeWidgetItem *)
 {
   if (columnsTree_->indexOfTopLevelItem(current) == 0)
     moveUpButton_->setEnabled(false);
