@@ -1,6 +1,6 @@
 /* ============================================================
  * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
- * Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+ * Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  * ============================================================ */
 #ifndef FEEDPROPERTIESDIALOG_H
 #define FEEDPROPERTIESDIALOG_H
@@ -109,6 +109,7 @@ typedef struct {
     int undeleteCount; //!< Number of all news
     int newCount; //!< Number of new news
     int unreadCount; //!< Number of unread news
+    int feedsCount; //!< Number of feeds
   } status;
 
 } FEED_PROPERTIES;
@@ -195,6 +196,7 @@ private:
   QLabel *createdFeed_;
   QLabel *lastUpdateFeed_;
   QLabel *newsCount_;
+  QLabel *feedsCount_;
   QWidget *createStatusTab();
 
   FEED_PROPERTIES feedProperties;
