@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 #ifndef NEWSTABWIDGET_H
 #define NEWSTABWIDGET_H
@@ -26,8 +26,9 @@
 #include <QtSql>
 #include <QtWebKit>
 
-#include "feedstreemodel.h"
-#include "feedstreeview.h"
+#include "feedsproxymodel.h"
+#include "feedsmodel.h"
+#include "feedsview.h"
 #include "findtext.h"
 #include "lineedit.h"
 #include "locationbar.h"
@@ -68,6 +69,8 @@ public:
   explicit NewsTabWidget(QWidget *parent, TabType type, int feedId = -1, int feedParId = -1);
   ~NewsTabWidget();
 
+  void disconnectObjects();
+
   void retranslateStrings();
   void setSettings(bool init = true, bool newTab = true);
   void setNewsLayout();
@@ -140,15 +143,15 @@ public:
 public slots:
   void setAutoLoadImages(bool apply = true);
   void slotNewsViewClicked(QModelIndex index);
-  void slotNewsViewSelected(QModelIndex index, bool clicked = false);
+  void slotNewsViewSelected(QModelIndex index, bool clicked=false);
   void slotNewsViewDoubleClicked(QModelIndex index);
   void slotNewsMiddleClicked(QModelIndex index);
-  void slotNewsUpPressed();
-  void slotNewsDownPressed();
-  void slotNewsHomePressed();
-  void slotNewsEndPressed();
-  void slotNewsPageUpPressed();
-  void slotNewsPageDownPressed();
+  void slotNewsUpPressed(QModelIndex index=QModelIndex());
+  void slotNewsDownPressed(QModelIndex index=QModelIndex());
+  void slotNewsHomePressed(QModelIndex index=QModelIndex());
+  void slotNewsEndPressed(QModelIndex index=QModelIndex());
+  void slotNewsPageUpPressed(QModelIndex index=QModelIndex());
+  void slotNewsPageDownPressed(QModelIndex index=QModelIndex());
   void slotSort(int column, int order);
 
 signals:
@@ -162,7 +165,7 @@ private slots:
   void slotSetItemStar(QModelIndex index, int starred);
   void slotMarkReadTimeout();
 
-  void setHtmlWebView(const QString &html, const QUrl &baseUrl);
+  void slotSetHtmlWebView(const QString &html, const QUrl &baseUrl);
   void webHomePage();
   void openPageInExternalBrowser();
   void slotLinkClicked(QUrl url);
@@ -197,9 +200,9 @@ private:
   QSqlDatabase db_;
   QWidget *newsWidget_;
 
-  FeedsTreeModel *feedsTreeModel_;
+  FeedsModel *feedsModel_;
   FeedsProxyModel *feedsProxyModel_;
-  FeedsTreeView *feedsTreeView_;
+  FeedsView *feedsView_;
 
   QFrame *lineWebWidget;
   QWidget *webWidget_;
