@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 #ifndef OPTIONSDIALOG_H
 #define OPTIONSDIALOG_H
@@ -160,22 +160,33 @@ public:
   QStringList idLabels_;
   QTreeWidget *labelsTree_;
 
-  // nitifier
-  QCheckBox *soundNewNews_;
+  // notifier
+  QGroupBox *soundNotifyBox_;
   QLineEdit *editSoundNotifer_;
   QPushButton *selectionSoundNotifer_;
   QPushButton *playSoundNotifer_;
 
   QGroupBox *showNotifyOn_;
+  QComboBox *screenNotify_;
   QComboBox *positionNotify_;
+  QSpinBox *transparencyNotify_;
   QSpinBox *countShowNewsNotify_;
   QSpinBox *timeShowNewsNotify_;
   QSpinBox *widthTitleNewsNotify_;
 
+  QCheckBox *showTitlesFeedsNotify_;
+  QCheckBox *showIconFeedNotify_;
+  QCheckBox *showButtonMarkAllNotify_;
+  QCheckBox *showButtonMarkReadNotify_;
+  QCheckBox *showButtonExBrowserNotify_;
+  QCheckBox *showButtonDeleteNotify_;
+
   QCheckBox *fullscreenModeNotify_;
+  QCheckBox *showNotifyInactiveApp_;
   QCheckBox *onlySelectedFeeds_;
   QTreeWidget *feedsTreeNotify_;
   bool itemNotChecked_;
+  Dialog *feedsNotifierDlg_;
 
   // language
   QString language();
@@ -264,7 +275,7 @@ private:
   QTabWidget *browserWidget_;
   QTabWidget *feedsWidget_;
   QWidget *labelsWidget_;
-  QFrame *notifierWidget_;
+  QTabWidget *notifierWidget_;
   QWidget *passwordsWidget_;
   QWidget *languageWidget_;
   QTabWidget *fontsColorsWidget_;
@@ -307,6 +318,7 @@ private:
 
   // notifier
   void createNotifierWidget();
+  void createFeedsNotifierDlg();
   void loadNotifier();
   void applyNotifier();
   bool loadNotifierOk_;
