@@ -1,6 +1,6 @@
 /* ============================================================
 * QuiteRSS is a open-source cross-platform RSS/Atom news feeds reader
-* Copyright (C) 2011-2014 QuiteRSS Team <quiterssteam@gmail.com>
+* Copyright (C) 2011-2016 QuiteRSS Team <quiterssteam@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -13,21 +13,22 @@
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* along with this program.  If not, see <https://www.gnu.org/licenses/>.
 * ============================================================ */
 #include "parseobject.h"
 
 #include "mainapplication.h"
 #include "database.h"
 #include "VersionNo.h"
+#include "common.h"
 
 #include <QDebug>
 #include <QDesktopServices>
 #include <QTextDocumentFragment>
-#include <QRegExp>
 #if defined(Q_OS_WIN)
 #include <windows.h>
 #endif
+#include <qzregexp.h>
 
 ParseObject::ParseObject(QObject *parent)
   : QObject(parent)
@@ -39,7 +40,7 @@ ParseObject::ParseObject(QObject *parent)
 
   parseTimer_ = new QTimer(this);
   parseTimer_->setSingleShot(true);
-  parseTimer_->setInterval(50);
+  parseTimer_->setInterval(10);
   connect(parseTimer_, SIGNAL(timeout()), this, SLOT(getQueuedXml()),
           Qt::QueuedConnection);
 
@@ -49,6 +50,12 @@ ParseObject::ParseObject(QObject *parent)
 
 ParseObject::~ParseObject()
 {
+
+}
+
+void ParseObject::disconnectObjects()
+{
+  disconnect(this);
 }
 
 /** @brief Queueing xml-data
@@ -135,8 +142,7 @@ void ParseObject::slotParse(const QByteArray &xmlData, const int &feedId,
   int errorLine;
   int errorColumn;
 
-  QRegExp rx("encoding=\"([^\"]+)",
-             Qt::CaseInsensitive, QRegExp::RegExp2);
+  QzRegExp rx("encoding=\"([^\"]+)", Qt::CaseInsensitive);
   int pos = rx.indexIn(xmlData);
   if (pos == -1) {
     rx.setPattern("encoding='([^']+)");
@@ -195,14 +201,43 @@ void ParseObject::slotParse(const QByteArray &xmlData, const int &feedId,
     feedType = rootElem.tagName();
     qDebug() << "Feed type: " << feedType;
 
+    q.exec(QString("SELECT id, guid, title, published, link_href FROM news WHERE feedId='%1'").
+           arg(parseFeedId_));
+    if (q.lastError().isValid()) {
+      qWarning() << __PRETTY_FUNCTION__ << __LINE__
+                 << "q.lastError(): " << q.lastError().text();
+    }
+    else {
+      while (q.next()) {
+        QString str = q.value(2).toString();
+        if (!str.isEmpty()) {
+        titleList_.append(str);
+
+        str = q.value(1).toString();
+        guidList_.append(str);
+
+        str = q.value(3).toString();
+        publishedList_.append(str);
+        str = q.value(4).toString();
+        linkList_.append(str);
+        }
+      }
+    }
+    q.finish();
+
     if (feedType == "feed") {
       parseAtom(feedUrl, doc);
     } else if ((feedType == "rss") || (feedType == "rdf:RDF")) {
       parseRss(feedUrl, doc);
     }
+
+    guidList_.clear();
+    titleList_.clear();
+    publishedList_.clear();
+    linkList_.clear();
   }
 
-  // Set feed update time and recieve data from server time
+  // Set feed update time and receive data from server time
   QString updated = QLocale::c().toString(QDateTime::currentDateTimeUtc(),
                                           "yyyy-MM-ddTHH:mm:ss");
   QString lastBuildDate = dtReply.toString(Qt::ISODate);
@@ -258,6 +293,13 @@ void ParseObject::parseAtom(const QString &feedUrl, const QDomDocument &doc)
         }
     }
   }
+
+  if (QUrl(feedItem.link).host().isEmpty() || (QUrl(feedItem.link).host().indexOf('.')) == -1) {
+    if (!feedItem.linkBase.isEmpty() && !QUrl(feedItem.linkBase).host().isEmpty())
+      feedItem.link = QUrl(feedItem.linkBase).scheme() %  "://" % QUrl(feedItem.linkBase).host();
+    else
+      feedItem.link = QUrl(feedUrl).scheme() %  "://" % QUrl(feedUrl).host();
+  }
   if (feedItem.linkBase.isEmpty() && !QUrl(feedItem.link).host().isEmpty())
     feedItem.linkBase = QUrl(feedItem.link).scheme() %  "://" % QUrl(feedItem.link).host();
   if (QUrl(feedItem.link).host().isEmpty())
@@ -299,8 +341,21 @@ void ParseObject::parseAtom(const QString &feedUrl, const QDomDocument &doc)
       newsItem.authorUri = authorElem.namedItem("uri").toElement().text();
       newsItem.authorEmail = authorElem.namedItem("email").toElement().text();
     }
+
     newsItem.description = newsList.item(i).namedItem("summary").toElement().text();
-    newsItem.content = newsList.item(i).namedItem("content").toElement().text();
+    QDomNode nodeContent = newsList.item(i).namedItem("content");
+    if (nodeContent.toElement().attribute("type") == "xhtml") {
+      QTextStream in(&newsItem.content);
+      nodeContent.save(in, 0);
+    } else {
+      newsItem.content = nodeContent.toElement().text();
+    }
+    if (!(newsItem.content.isEmpty() ||
+          (newsItem.description.length() > newsItem.content.length()))) {
+      newsItem.description = newsItem.content;
+    }
+    newsItem.content.clear();
+
     QDomNodeList categoryElem = newsList.item(i).toElement().elementsByTagName("category");
     for (int j = 0; j < categoryElem.size(); j++) {
       if (!newsItem.category.isEmpty()) newsItem.category.append(", ");
@@ -347,120 +402,115 @@ void ParseObject::parseAtom(const QString &feedUrl, const QDomDocument &doc)
       newsItem.linkAlternate.clear();
     }
 
-    addAtomNewsIntoBase(newsItem);
+    addAtomNewsIntoBase(&newsItem);
   }
 }
 
-void ParseObject::addAtomNewsIntoBase(NewsItemStruct &newsItem)
+void ParseObject::addAtomNewsIntoBase(NewsItemStruct *newsItem)
 {
+  Common::sleep(5);
+
   // search news duplicates in base
   QSqlQuery q(db_);
   q.setForwardOnly(true);
   QString qStr;
-  qDebug() << "atomId:" << newsItem.id;
-  qDebug() << "title:" << newsItem.title;
-  qDebug() << "published:" << newsItem.updated;
+  qDebug() << "atomId:" << newsItem->id;
+  qDebug() << "title:" << newsItem->title;
+  qDebug() << "published:" << newsItem->updated;
 
-  if (!newsItem.updated.isEmpty()) {  // search by pubDate
-    if (!duplicateNewsMode_)
-      qStr.append("AND published=:published");
-  } else {
-    qStr.append("AND title LIKE :title");
-  }
-
-  if (!newsItem.id.isEmpty()) {       // search by guid
-    if (duplicateNewsMode_) {
-      q.prepare("SELECT * FROM news WHERE feedId=:id AND guid=:guid");
-    } else {
-      q.prepare(QString("SELECT * FROM news WHERE feedId=:id AND guid=:guid %1").arg(qStr));
-      if (!newsItem.updated.isEmpty()) {    // search by pubDate
-        q.bindValue(":published", newsItem.updated);
-      } else {
-        q.bindValue(":title", newsItem.title);
+  bool isDuplicate = false;
+  for (int i = 0; i < guidList_.count(); ++i) {
+    if (!newsItem->id.isEmpty()) {         // search by guid if present
+      if (guidList_.at(i) == newsItem->id) {
+        if (duplicateNewsMode_) {       // autodelete duplicate news enabled
+          isDuplicate = true;
+        } else {                        // autodelete dupl. news disabled
+          if (!newsItem->updated.isEmpty()) {  // search by pubDate if present
+            if (publishedList_.at(i) == newsItem->updated)
+              isDuplicate = true;
+          } else {                      // ... or by title
+            if (titleList_.at(i) == newsItem->title)
+              isDuplicate = true;
+          }
+        }
+      }
+    } else {                                // guid is absent
+      if (!newsItem->updated.isEmpty()) {    // search by pubDate if present
+        if (publishedList_.at(i) == newsItem->updated)
+          isDuplicate = true;
+      } else {                              // ... or by title
+        if (titleList_.at(i) == newsItem->title)
+          isDuplicate = true;
       }
     }
-    q.bindValue(":guid", newsItem.id);
-  } else {
-    q.prepare(QString("SELECT * FROM news WHERE feedId=:id %1").arg(qStr));
-    if (!newsItem.updated.isEmpty()) {    // search by pubDate
-      if (!duplicateNewsMode_)
-        q.bindValue(":published", newsItem.updated);
-    } else {
-      q.bindValue(":title", newsItem.title);
-    }
+    if (isDuplicate) break;
   }
-  q.bindValue(":id", parseFeedId_);
-  q.exec();
 
-  // Check request correctness
-  if (q.lastError().isValid())
-    qDebug() << "ERROR: q.exec(" << qStr << ") -> " << q.lastError().text();
-  else {
-    // if duplicates not found, add news into base
-    if (!q.first()) {
-      bool read = false;
-      if (mainApp->mainWindow()->markIdenticalNewsRead_) {
-        q.prepare("SELECT id FROM news WHERE title LIKE :title AND feedId!=:id");
-        q.bindValue(":id", parseFeedId_);
-        q.bindValue(":title", newsItem.title);
-        q.exec();
-        if (q.first()) read = true;
-      }
-
-      qStr = QString("INSERT INTO news("
-                     "feedId, description, content, guid, title, author_name, "
-                     "author_uri, author_email, published, received, "
-                     "link_href, link_alternate, category, comments, "
-                     "enclosure_url, enclosure_type, enclosure_length, new, read) "
-                     "VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
-      q.prepare(qStr);
-      q.addBindValue(parseFeedId_);
-      q.addBindValue(newsItem.description);
-      q.addBindValue(newsItem.content);
-      q.addBindValue(newsItem.id);
-      q.addBindValue(newsItem.title);
-      q.addBindValue(newsItem.author);
-      q.addBindValue(newsItem.authorUri);
-      q.addBindValue(newsItem.authorEmail);
-      if (newsItem.updated.isEmpty())
-        newsItem.updated = QDateTime::currentDateTimeUtc().toString(Qt::ISODate);
-      q.addBindValue(newsItem.updated);
-      q.addBindValue(QDateTime::currentDateTime().toString(Qt::ISODate));
-      q.addBindValue(newsItem.link);
-      q.addBindValue(newsItem.linkAlternate);
-      q.addBindValue(newsItem.category);
-      q.addBindValue(newsItem.comments);
-      q.addBindValue(newsItem.eUrl);
-      q.addBindValue(newsItem.eType);
-      q.addBindValue(newsItem.eLength);
-      q.addBindValue(read ? 0 : 1);
-      q.addBindValue(read ? 2 : 0);
-      if (!q.exec()) {
-        qWarning() << __PRETTY_FUNCTION__ << __LINE__
-                   << "q.lastError(): " << q.lastError().text();
-      }
-      qDebug() << "q.exec(" << q.lastQuery() << ")";
-      qDebug() << "       " << parseFeedId_;
-      qDebug() << "       " << newsItem.description;
-      qDebug() << "       " << newsItem.content;
-      qDebug() << "       " << newsItem.id;
-      qDebug() << "       " << newsItem.title;
-      qDebug() << "       " << newsItem.author;
-      qDebug() << "       " << newsItem.authorUri;
-      qDebug() << "       " << newsItem.authorEmail;
-      qDebug() << "       " << newsItem.updated;
-      qDebug() << "       " << QDateTime::currentDateTime().toString();
-      qDebug() << "       " << newsItem.link;
-      qDebug() << "       " << newsItem.linkAlternate;
-      qDebug() << "       " << newsItem.category;
-      qDebug() << "       " << newsItem.comments;
-      qDebug() << "       " << newsItem.eUrl;
-      qDebug() << "       " << newsItem.eType;
-      qDebug() << "       " << newsItem.eLength;
-      feedChanged_ = true;
+  // if duplicates not found, add news into base
+  if (!isDuplicate) {
+    bool read = false;
+    if (mainApp->mainWindow()->markIdenticalNewsRead_) {
+      q.prepare("SELECT id FROM news WHERE title LIKE :title AND feedId!=:id");
+      q.bindValue(":id", parseFeedId_);
+      q.bindValue(":title", newsItem->title);
+      q.exec();
+      if (q.first()) read = true;
     }
+
+    qStr = QString("INSERT INTO news("
+                   "feedId, description, content, guid, title, author_name, "
+                   "author_uri, author_email, published, received, "
+                   "link_href, link_alternate, category, comments, "
+                   "enclosure_url, enclosure_type, enclosure_length, new, read) "
+                   "VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
+    q.prepare(qStr);
+    q.addBindValue(parseFeedId_);
+    q.addBindValue(newsItem->description);
+    q.addBindValue(newsItem->content);
+    q.addBindValue(newsItem->id);
+    q.addBindValue(newsItem->title);
+    q.addBindValue(newsItem->author);
+    q.addBindValue(newsItem->authorUri);
+    q.addBindValue(newsItem->authorEmail);
+    QString updated = newsItem->updated;
+    if (updated.isEmpty())
+      updated = QDateTime::currentDateTimeUtc().toString(Qt::ISODate);
+    q.addBindValue(updated);
+    q.addBindValue(QDateTime::currentDateTime().toString(Qt::ISODate));
+    q.addBindValue(newsItem->link);
+    q.addBindValue(newsItem->linkAlternate);
+    q.addBindValue(newsItem->category);
+    q.addBindValue(newsItem->comments);
+    q.addBindValue(newsItem->eUrl);
+    q.addBindValue(newsItem->eType);
+    q.addBindValue(newsItem->eLength);
+    q.addBindValue(read ? 0 : 1);
+    q.addBindValue(read ? 2 : 0);
+    if (!q.exec()) {
+      qWarning() << __PRETTY_FUNCTION__ << __LINE__
+                 << "q.lastError(): " << q.lastError().text();
+    }
+    q.finish();
+    qDebug() << "q.exec(" << q.lastQuery() << ")";
+    qDebug() << "       " << parseFeedId_;
+    qDebug() << "       " << newsItem->description;
+    qDebug() << "       " << newsItem->content;
+    qDebug() << "       " << newsItem->id;
+    qDebug() << "       " << newsItem->title;
+    qDebug() << "       " << newsItem->author;
+    qDebug() << "       " << newsItem->authorUri;
+    qDebug() << "       " << newsItem->authorEmail;
+    qDebug() << "       " << newsItem->updated;
+    qDebug() << "       " << QDateTime::currentDateTime().toString();
+    qDebug() << "       " << newsItem->link;
+    qDebug() << "       " << newsItem->linkAlternate;
+    qDebug() << "       " << newsItem->category;
+    qDebug() << "       " << newsItem->comments;
+    qDebug() << "       " << newsItem->eUrl;
+    qDebug() << "       " << newsItem->eType;
+    qDebug() << "       " << newsItem->eLength;
+    feedChanged_ = true;
   }
-  q.finish();
 }
 
 void ParseObject::parseRss(const QString &feedUrl, const QDomDocument &doc)
@@ -471,6 +521,8 @@ void ParseObject::parseRss(const QString &feedUrl, const QDomDocument &doc)
   feedItem.title = toPlainText(channel.namedItem("title").toElement().text());
   feedItem.description = channel.namedItem("description").toElement().text();
   feedItem.link = toPlainText(channel.namedItem("link").toElement().text());
+  if (QUrl(feedItem.link).host().isEmpty())
+    feedItem.link = QUrl(feedUrl).scheme() %  "://" % QUrl(feedUrl).host() + feedItem.link;
   feedItem.updated = channel.namedItem("pubDate").toElement().text();
   if (feedItem.updated.isEmpty())
     feedItem.updated = channel.namedItem("pubdate").toElement().text();
@@ -513,8 +565,17 @@ void ParseObject::parseRss(const QString &feedUrl, const QDomDocument &doc)
       if (newsList.item(i).namedItem("guid").toElement().attribute("isPermaLink") == "true")
         newsItem.link = newsItem.id;
     }
+    if (QUrl(newsItem.link).host().isEmpty())
+      newsItem.link = QUrl(feedUrl).scheme() %  "://" % QUrl(feedUrl).host() + newsItem.link;
+
     newsItem.description = newsList.item(i).namedItem("description").toElement().text();
     newsItem.content = newsList.item(i).namedItem("content:encoded").toElement().text();
+    if (newsItem.content.isEmpty() || (newsItem.description.length() > newsItem.content.length())) {
+      newsItem.content.clear();
+    } else {
+      newsItem.description = newsItem.content;
+    }
+
     QDomNodeList categoryElem = newsList.item(i).toElement().elementsByTagName("category");
     for (int j = 0; j < categoryElem.size(); j++) {
       if (!newsItem.category.isEmpty()) newsItem.category.append(", ");
@@ -534,111 +595,156 @@ void ParseObject::parseRss(const QString &feedUrl, const QDomDocument &doc)
       }
     }
 
-    addRssNewsIntoBase(newsItem);
+    addRssNewsIntoBase(&newsItem);
   }
 }
 
-void ParseObject::addRssNewsIntoBase(NewsItemStruct &newsItem)
+void ParseObject::addRssNewsIntoBase(NewsItemStruct *newsItem)
 {
+  Common::sleep(5);
+
   // search news duplicates in base
   QSqlQuery q(db_);
   q.setForwardOnly(true);
   QString qStr;
-  QString qStr1;
-  qDebug() << "guid:     " << newsItem.id;
-  qDebug() << "link_href:" << newsItem.link;
-  qDebug() << "title:"     << newsItem.title;
-  qDebug() << "published:" << newsItem.updated;
+  qDebug() << "guid:     " << newsItem->id;
+  qDebug() << "link_href:" << newsItem->link;
+  qDebug() << "title:"     << newsItem->title;
+  qDebug() << "published:" << newsItem->updated;
 
-  if (!newsItem.updated.isEmpty()) {  // search by pubDate
-    if (!duplicateNewsMode_)
-      qStr.append(" AND published=:published");
-    qStr1.append(" OR (title LIKE :title AND published=:published)");
-  } else {
-    qStr.append(" AND title LIKE :title");
-  }
-
-  if (!newsItem.id.isEmpty()) {       // search by guid
-    q.prepare(QString("SELECT * FROM news WHERE feedId=:id AND ((guid=:guid%1)%2)").
-              arg(qStr).arg(qStr1));
-    q.bindValue(":guid", newsItem.id);
-  } else if (!newsItem.link.isEmpty()) {   // search by link_href
-    q.prepare(QString("SELECT * FROM news WHERE feedId=:id AND ((link_href=:link_href%1)%2)").
-              arg(qStr).arg(qStr1));
-    q.bindValue(":link_href", newsItem.link);
-  } else {
-    qStr.remove(" AND ");
-    q.prepare(QString("SELECT * FROM news WHERE feedId=:id AND (%1%2)").arg(qStr).arg(qStr1));
-  }
-  q.bindValue(":id", parseFeedId_);
-  if (!newsItem.updated.isEmpty()) {    // search by pubDate
-    q.bindValue(":published", newsItem.updated);
-  }
-  q.bindValue(":title", newsItem.title);
-  q.exec();
-
-  // Check request correctness
-  if (q.lastError().isValid())
-    qDebug() << "ERROR: q.exec(" << qStr << ") -> " << q.lastError().text();
-  else {
-    // if duplicates not found, add news into base
-    if (!q.first()) {
-      bool read = false;
-      if (mainApp->mainWindow()->markIdenticalNewsRead_) {
-        q.prepare("SELECT id FROM news WHERE title LIKE :title AND feedId!=:id");
-        q.bindValue(":id", parseFeedId_);
-        q.bindValue(":title", newsItem.title);
-        q.exec();
-        if (q.first()) read = true;
+  bool isDuplicate = false;
+  for (int i = 0; i < guidList_.count(); ++i) {
+    if (!newsItem->id.isEmpty()) {         // search by guid if present
+      if (guidList_.at(i) == newsItem->id) {
+        if (!newsItem->updated.isEmpty()) {  // search by pubDate if present
+          if (!duplicateNewsMode_) {
+            if (publishedList_.at(i) == newsItem->updated)
+              isDuplicate = true;
+          }
+          else {
+            isDuplicate = true;
+          }
+        } else {                            // ... or by title
+          if (titleList_.at(i) == newsItem->title)
+            isDuplicate = true;
+        }
       }
-
-      qStr = QString("INSERT INTO news("
-                     "feedId, description, content, guid, title, author_name, "
-                     "published, received, link_href, category, comments, "
-                     "enclosure_url, enclosure_type, enclosure_length, new, read) "
-                     "VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
-      q.prepare(qStr);
-      q.addBindValue(parseFeedId_);
-      q.addBindValue(newsItem.description);
-      q.addBindValue(newsItem.content);
-      q.addBindValue(newsItem.id);
-      q.addBindValue(newsItem.title);
-      q.addBindValue(newsItem.author);
-      if (newsItem.updated.isEmpty())
-        newsItem.updated = QDateTime::currentDateTimeUtc().toString(Qt::ISODate);
-      q.addBindValue(newsItem.updated);
-      q.addBindValue(QDateTime::currentDateTime().toString(Qt::ISODate));
-      q.addBindValue(newsItem.link);
-      q.addBindValue(newsItem.category);
-      q.addBindValue(newsItem.comments);
-      q.addBindValue(newsItem.eUrl);
-      q.addBindValue(newsItem.eType);
-      q.addBindValue(newsItem.eLength);
-      q.addBindValue(read ? 0 : 1);
-      q.addBindValue(read ? 2 : 0);
-      if (!q.exec()) {
-        qWarning() << __PRETTY_FUNCTION__ << __LINE__
-                   << "q.lastError(): " << q.lastError().text();
+      if (!isDuplicate) {
+        if (!newsItem->updated.isEmpty()) {
+          if ((publishedList_.at(i) == newsItem->updated) &&
+              (titleList_.at(i) == newsItem->title)) {
+            isDuplicate = true;
+          }
+        }
       }
-      qDebug() << "q.exec(" << q.lastQuery() << ")";
-      qDebug() << "       " << parseFeedId_;
-      qDebug() << "       " << newsItem.description;
-      qDebug() << "       " << newsItem.content;
-      qDebug() << "       " << newsItem.id;
-      qDebug() << "       " << newsItem.title;
-      qDebug() << "       " << newsItem.author;
-      qDebug() << "       " << newsItem.updated;
-      qDebug() << "       " << QDateTime::currentDateTime().toString();
-      qDebug() << "       " << newsItem.link;
-      qDebug() << "       " << newsItem.category;
-      qDebug() << "       " << newsItem.comments;
-      qDebug() << "       " << newsItem.eUrl;
-      qDebug() << "       " << newsItem.eType;
-      qDebug() << "       " << newsItem.eLength;
-      feedChanged_ = true;
     }
+    else if (!newsItem->link.isEmpty()) {   // search by link_href
+      if (linkList_.at(i) == newsItem->link) {
+        if (!newsItem->updated.isEmpty()) {  // search by pubDate if present
+          if (!duplicateNewsMode_) {
+            if (publishedList_.at(i) == newsItem->updated)
+              isDuplicate = true;
+          }
+          else {
+            isDuplicate = true;
+          }
+        } else {                            // ... or by title
+          if (titleList_.at(i) == newsItem->title)
+            isDuplicate = true;
+        }
+      }
+      if (!isDuplicate) {
+        if (!newsItem->updated.isEmpty()) {
+          if ((publishedList_.at(i) == newsItem->updated) &&
+              (titleList_.at(i) == newsItem->title)) {
+            isDuplicate = true;
+          }
+        }
+      }
+    }
+    else {                                // guid is absent
+      if (!newsItem->updated.isEmpty()) {  // search by pubDate if present
+        if (!duplicateNewsMode_) {
+          if (publishedList_.at(i) == newsItem->updated)
+            isDuplicate = true;
+        }
+        else {
+          isDuplicate = true;
+        }
+      } else {                            // ... or by title
+        if (titleList_.at(i) == newsItem->title)
+          isDuplicate = true;
+      }
+      if (!isDuplicate) {
+        if (!newsItem->updated.isEmpty()) {
+          if ((publishedList_.at(i) == newsItem->updated) &&
+              (titleList_.at(i) == newsItem->title)) {
+            isDuplicate = true;
+          }
+        }
+      }
+    }
+    if (isDuplicate) break;
+  }
+
+  // if duplicates not found, add news into base
+  if (!isDuplicate) {
+    bool read = false;
+    if (mainApp->mainWindow()->markIdenticalNewsRead_) {
+      q.prepare("SELECT id FROM news WHERE title LIKE :title AND feedId!=:id");
+      q.bindValue(":id", parseFeedId_);
+      q.bindValue(":title", newsItem->title);
+      q.exec();
+      if (q.first()) read = true;
+    }
+
+    qStr = QString("INSERT INTO news("
+                   "feedId, description, content, guid, title, author_name, "
+                   "published, received, link_href, category, comments, "
+                   "enclosure_url, enclosure_type, enclosure_length, new, read) "
+                   "VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
+    q.prepare(qStr);
+    q.addBindValue(parseFeedId_);
+    q.addBindValue(newsItem->description);
+    q.addBindValue(newsItem->content);
+    q.addBindValue(newsItem->id);
+    q.addBindValue(newsItem->title);
+    q.addBindValue(newsItem->author);
+    QString updated = newsItem->updated;
+    if (updated.isEmpty())
+      updated = QDateTime::currentDateTimeUtc().toString(Qt::ISODate);
+    q.addBindValue(updated);
+    q.addBindValue(QDateTime::currentDateTime().toString(Qt::ISODate));
+    q.addBindValue(newsItem->link);
+    q.addBindValue(newsItem->category);
+    q.addBindValue(newsItem->comments);
+    q.addBindValue(newsItem->eUrl);
+    q.addBindValue(newsItem->eType);
+    q.addBindValue(newsItem->eLength);
+    q.addBindValue(read ? 0 : 1);
+    q.addBindValue(read ? 2 : 0);
+    if (!q.exec()) {
+      qWarning() << __PRETTY_FUNCTION__ << __LINE__
+                 << "q.lastError(): " << q.lastError().text();
+    }
+    q.finish();
+    qDebug() << "q.exec(" << q.lastQuery() << ")";
+    qDebug() << "       " << parseFeedId_;
+    qDebug() << "       " << newsItem->description;
+    qDebug() << "       " << newsItem->content;
+    qDebug() << "       " << newsItem->id;
+    qDebug() << "       " << newsItem->title;
+    qDebug() << "       " << newsItem->author;
+    qDebug() << "       " << newsItem->updated;
+    qDebug() << "       " << QDateTime::currentDateTime().toString();
+    qDebug() << "       " << newsItem->link;
+    qDebug() << "       " << newsItem->category;
+    qDebug() << "       " << newsItem->comments;
+    qDebug() << "       " << newsItem->eUrl;
+    qDebug() << "       " << newsItem->eType;
+    qDebug() << "       " << newsItem->eLength;
+    feedChanged_ = true;
   }
-  q.finish();
 }
 
 QString ParseObject::toPlainText(const QString &text)
@@ -694,6 +800,8 @@ QString ParseObject::parseDate(const QString &dateString, const QString &urlStri
 
     temp = ds.left(20);
     timeZone = ds.mid(temp.length()+1, 3);
+    if (timeZone.contains("EDT"))
+      timeZone="-4";
     if (timeZone.isEmpty()) timeZone = QString::number(nTimeShift);
     dt = locale.toDateTime(temp, "dd MMM yyyy HH:mm:ss");
     if (dt.isValid()) return locale.toString(dt.addSecs(timeZone.toInt() * -3600), "yyyy-MM-ddTHH:mm:ss");
@@ -769,6 +877,7 @@ void ParseObject::runUserFilter(int feedId, int filterId)
     QString qStr1;
     QString qStr2;
     QString whereStr;
+    QList<int> idLabelsList;
     QStringList soundList;
     QStringList colorList;
 
@@ -792,7 +901,7 @@ void ParseObject::runUserFilter(int feedId, int filterId)
                      arg(QDateTime::currentDateTime().toString(Qt::ISODate)));
         break;
       case 3: // action -> Add Label
-        qStr2.append(QString("%1,").arg(q1.value(1).toInt()));
+        idLabelsList.append(q1.value(1).toInt());
         break;
       case 4: // action -> Play Sound
         soundList.append(q1.value(1).toString());
@@ -803,11 +912,6 @@ void ParseObject::runUserFilter(int feedId, int filterId)
       }
     }
 
-    if (!qStr2.isEmpty()) {
-      if (!qStr1.isNull()) qStr1.append(",");
-      qStr1.append(QString(" label=',%1'").arg(qStr2));
-    }
-
     if (qStr1.isEmpty())
       qStr.clear();
     else
@@ -955,7 +1059,7 @@ void ParseObject::runUserFilter(int feedId, int filterId)
             qStr1.append(QString("link_href NOT LIKE '%%1%' ").arg(content));
             break;
           case 2: // condition -> is
-            qStr1.append(QString("Ulink_href LIKE '%1' ").arg(content));
+            qStr1.append(QString("link_href LIKE '%1' ").arg(content));
             break;
           case 3: // condition -> isn't
             qStr1.append(QString("link_href NOT LIKE '%1' ").arg(content));
@@ -971,43 +1075,65 @@ void ParseObject::runUserFilter(int feedId, int filterId)
             break;
           }
           break;
+        case 6: // field -> News
+          switch (q1.value(1).toInt()) {
+          case 0: // condition -> contains
+            qStr1.append(QString("(UPPER(title) LIKE '%%1%' OR UPPER(description) LIKE '%%1%') ").arg(content.toUpper()));
+            break;
+          case 1: // condition -> doesn't contains
+            qStr1.append(QString("(UPPER(title) NOT LIKE '%%1%' OR UPPER(description) NOT LIKE '%%1%') ").arg(content.toUpper()));
+            break;
+          case 2: // condition -> regExp
+            qStr1.append(QString("(title REGEXP '%1' OR description REGEXP '%1') ").arg(content));
+            break;
+          }
+          break;
         }
       }
       whereStr.append(qStr1).append(")");
     }
 
-    if (!qStr.isEmpty()) {
-      qStr.append(whereStr);
-      if (!q1.exec(qStr)) {
-        qWarning() << __PRETTY_FUNCTION__ << __LINE__
-                   << "q.lastError(): " << q1.lastError().text();
-      }
-    }
+    if (q1.exec(QString("SELECT id, label FROM news").append(whereStr))) {
+      QSqlQuery q2(db_);
+      bool isPlaySound = false;
 
-    if (!soundList.isEmpty()) {
-      qStr = "SELECT * FROM news";
-      qStr.append(whereStr);
-      if (q1.exec(qStr)) {
-        if (q1.first()) {
-          emit signalPlaySound(soundList.at(0));
+      while (q1.next()) {
+        if (!qStr.isEmpty()) {
+          qStr1 = qStr % QString(" WHERE id='%1'").arg(q1.value(0).toInt());
+          if (!q2.exec(qStr1)) {
+            qWarning() << __PRETTY_FUNCTION__ << __LINE__
+                       << "q.lastError(): " << q2.lastError().text();
+          }
         }
-      } else {
-        qWarning() << __PRETTY_FUNCTION__ << __LINE__
-                   << "q.lastError(): " << q1.lastError().text();
-      }
-    }
 
-    if (!colorList.isEmpty()) {
-      qStr = "SELECT id FROM news";
-      qStr.append(whereStr);
-      if (q1.exec(qStr)) {
-        while (q1.next()) {
+        if (!idLabelsList.isEmpty()) {
+          QString idLabelsStr = q1.value(1).toString();
+          foreach (int idLabel, idLabelsList) {
+            if (idLabelsStr.contains(QString(",%1,").arg(idLabel))) continue;
+            if (idLabelsStr.isEmpty()) idLabelsStr.append(",");
+            idLabelsStr.append(QString("%1,").arg(idLabel));
+
+          }
+          qStr1 = QString("UPDATE news SET label='%1' WHERE id='%2'").arg(idLabelsStr).
+              arg(q1.value(0).toInt());
+          if (!q2.exec(qStr1)) {
+            qWarning() << __PRETTY_FUNCTION__ << __LINE__
+                       << "q.lastError(): " << q2.lastError().text();
+          }
+        }
+
+        if (!colorList.isEmpty()) {
           emit signalAddColorList(q1.value(0).toInt(), colorList.at(0));
         }
-      } else {
-        qWarning() << __PRETTY_FUNCTION__ << __LINE__
-                   << "q.lastError(): " << q1.lastError().text();
+
+        isPlaySound = true;
       }
+
+      if (isPlaySound && !soundList.isEmpty())
+        emit signalPlaySound(soundList.at(0));
+    } else {
+      qWarning() << __PRETTY_FUNCTION__ << __LINE__
+                 << "q.lastError(): " << q1.lastError().text();
     }
 
   }
